@@ -23,7 +23,7 @@ class Model(dc.Model):
     >>> signal.id = "id"
     """
 
-    DATAFILE = "datafile"
+    DOCUMENT = "document"
     SECTION = "section"
     PROPERTY = "property"
     VALUE = "value"
@@ -78,12 +78,10 @@ class Model(dc.Model):
         :returns: The location prefix.
         :rtype: str
         """
-        if type_name == cls.DATAFILE:
-            return 'datafiles/datafile'
-        elif type_name in (cls.SECTION, cls.PROPERTY, cls.VALUE):
-            return 'metadata/' + type_name
+        if type_name in (cls.DOCUMENT, cls.SECTION, cls.PROPERTY, cls.VALUE):
+            return "/api/v1/metadata/" + type_name + "/"
         else:
-            return 'electrophysiology/' + type_name
+            return "/api/v1/electrophysiology/" + type_name + "/"
 
     #
     # Fields
@@ -91,17 +89,38 @@ class Model(dc.Model):
 
     id          = Field(field_type=str)
     guid        = Field(field_type=str)
-    permalink   = Field(field_type=str)
+    resource_uri= Field(field_type=str)
     location    = Field(field_type=str)
     model       = Field(field_type=str)
 
 
+class DocumentModel(Model):
+    model       = Field(field_type=str, default=Model.DOCUMENT)
+    author      = Field(field_type=str)
+    date        = Field(field_type=str)
+    version     = Field(field_type=str)
+    repository  = Field(field_type=str)
+
+    sections    = FChildren(type_info=Model.SECTION)
+
+
+Model._MODEL_MAP[Model.DOCUMENT] = DocumentModel
+
+
 class SectionModel(Model):
     model       = Field(field_type=str, default=Model.SECTION)
     name        = Field(field_type=str, obligatory=True)
+    type        = Field(field_type=str)
+    reference   = Field(field_type=str)
     description = Field(field_type=str)
+    definition  = Field(field_type=str)
+    link        = Field(field_type=str)
+    include     = Field(field_type=str)
+    repository  = Field(field_type=str)
+    mapping     = Field(field_type=str)
 
-    parent      = FParent(type_info=Model.SECTION, name_mapping="parent_section", obligatory=True)
+    document      = FParent(type_info=Model.DOCUMENT)
+    section     = FParent(type_info=Model.SECTION)
     sections    = FChildren(type_info=Model.SECTION)
     properties  = FChildren(type_info=Model.PROPERTY)
     blocks      = FChildren(type_info=Model.BLOCK)
@@ -112,6 +131,10 @@ Model._MODEL_MAP[Model.SECTION] = SectionModel
 class PropertyModel(Model):
     model       = Field(field_type=str, default=Model.PROPERTY)
     name        = Field(field_type=str, obligatory=True)
+    definition  = Field(field_type=str)
+    mapping     = Field(field_type=str)
+    dependency  = Field(field_type=str)
+    dependencyvalue = Field(field_type=str)
 
     parent      = FParent(type_info=Model.SECTION, name_mapping="section")
     values      = FChildren(type_info=Model.VALUE, obligatory=True)
@@ -121,9 +144,16 @@ Model._MODEL_MAP[Model.PROPERTY] = PropertyModel
 
 class ValueModel(Model):
     model       = Field(field_type=str, default=Model.VALUE)
-    data       = Field(field_type=str, obligatory=True)
+    data        = Field(field_type=str, obligatory=True)
+    uncertainty     = Field(field_type=str)
+    unit            = Field(field_type=str)
+    reference       = Field(field_type=str)
+    definition      = Field(field_type=str)
+    filename        = Field(field_type=str)
+    encoder         = Field(field_type=str)
+    checksum        = Field(field_type=str)
 
-    parent      = FParent(type_info=Model.PROPERTY, name_mapping="parent_property")
+    parent          = FParent(type_info=Model.PROPERTY, name_mapping="property")
 
 Model._MODEL_MAP[Model.VALUE] = ValueModel
 
@@ -135,9 +165,9 @@ class BlockModel(Model):
     description = Field(field_type=str)
 
     section                = FParent(type_info=Model.SECTION)
-    metadata               = FChildren(type_info=Model.VALUE, name_mapping="metadata")
     recordingchannelgroups = FChildren(type_info=Model.RECORDINGCHANNELGROUP)
     segments               = FChildren(type_info=Model.SEGMENT)
+    section               = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.BLOCK] = BlockModel
 
@@ -149,14 +179,16 @@ class SegmentModel(Model):
 
     block       = FParent(type_info=Model.BLOCK)
 
-    metadata                  = FChildren(type_info=Model.VALUE, name_mapping="metadata")
     analogsignals             = FChildren(type_info=Model.ANALOGSIGNAL)
     irregularlysampledsignals = FChildren(type_info=Model.IRREGULARLYSAMPLEDSIGNAL)
     analogsignalarrays        = FChildren(type_info=Model.ANALOGSIGNALARRAY)
     spiketrains               = FChildren(type_info=Model.SPIKETRAIN)
     spikes                    = FChildren(type_info=Model.SPIKE)
     events                    = FChildren(type_info=Model.EVENT)
+    eventarrays               = FChildren(type_info=Model.EVENTARRAY)
     epochs                    = FChildren(type_info=Model.EPOCH)
+    epocharrays               = FChildren(type_info=Model.EPOCHARRAY)
+    section                  = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.SEGMENT] = SegmentModel
 
@@ -166,10 +198,11 @@ class EventArrayModel(Model):
     name        = Field(field_type=str)
     description = Field(field_type=str)
 
+    labels      = FDatafile(obligatory=True)
     times       = FDatafile(obligatory=True)
 
     segment     = FParent(type_info=Model.SEGMENT)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.EVENTARRAY] = EventArrayModel
 
@@ -183,7 +216,7 @@ class EventModel(Model):
     time        = FQuantity(obligatory=True)
 
     segment     = FParent(type_info=Model.SEGMENT)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.EVENT] = EventModel
 
@@ -198,7 +231,7 @@ class EpochArrayModel(Model):
     durations   = FDatafile(obligatory=True)
 
     segment     = FParent(type_info=Model.SEGMENT)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.EPOCHARRAY] = EpochArrayModel
 
@@ -213,7 +246,7 @@ class EpochModel(Model):
     duration    = FQuantity(obligatory=True)
 
     segment     = FParent(type_info=Model.SEGMENT)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.EPOCH] = EpochModel
 
@@ -224,10 +257,10 @@ class RecordingChannelGroupModel(Model):
     description = Field(field_type=str)
 
     block       = FParent(type_info=Model.BLOCK)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
     units       = FChildren(type_info=Model.UNIT)
     recordingchannels   = FChildren(type_info=Model.RECORDINGCHANNEL)
     analogsignalarrays  = FChildren(type_info=Model.ANALOGSIGNALARRAY)
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.RECORDINGCHANNELGROUP] = RecordingChannelGroupModel
 
@@ -238,10 +271,10 @@ class RecordingChannelModel(Model):
     description = Field(field_type=str)
     index       = Field(field_type=int, default=0)
 
-    metadata                  = FChildren(type_info=Model.VALUE, name_mapping="metadata")
     recordingchannelgroups    = FChildren(type_info=Model.RECORDINGCHANNELGROUP, name_mapping="recordingchannelgroup")
     analogsignals             = FChildren(type_info=Model.ANALOGSIGNAL)
     irregularlysampledsignals = FChildren(type_info=Model.IRREGULARLYSAMPLEDSIGNAL)
+    section                  = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.RECORDINGCHANNEL] = RecordingChannelModel
 
@@ -252,9 +285,9 @@ class UnitModel(Model):
     description = Field(field_type=str)
 
     recordingchannelgroup   = FParent(type_info=Model.RECORDINGCHANNELGROUP)
-    metadata                = FChildren(type_info=Model.VALUE, name_mapping="metadata")
     spikes                  = FChildren(type_info=Model.SPIKE)
     spiketrains             = FChildren(type_info=Model.SPIKETRAIN)
+    section                = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.UNIT] = UnitModel
 
@@ -264,14 +297,14 @@ class SpikeTrainModel(Model):
     name        = Field(field_type=str)
     description = Field(field_type=str)
 
-    t_start     = FQuantity()
+    t_start     = FQuantity(obligatory=True)
     t_stop      = FQuantity(obligatory=True)
     times       = FDatafile(obligatory=True)
     waveforms   = FDatafile()
 
     unit        = FParent(type_info=Model.UNIT)
     segment     = FParent(type_info=Model.SEGMENT)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.SPIKETRAIN] = SpikeTrainModel
 
@@ -288,7 +321,7 @@ class SpikeModel(Model):
 
     unit        = FParent(type_info=Model.UNIT)
     segment     = FParent(type_info=Model.SEGMENT)
-    metadata    = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section    = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.SPIKE] = SpikeModel
 
@@ -304,7 +337,7 @@ class AnalogsignalArrayModel(Model):
 
     segment                 = FParent(type_info=Model.SEGMENT)
     recordingchannelgroup   = FParent(type_info=Model.RECORDINGCHANNELGROUP)
-    metadata                = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section                = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.ANALOGSIGNALARRAY] = AnalogsignalArrayModel
 
@@ -320,7 +353,7 @@ class AnalogsignalModel(Model):
 
     segment          = FParent(type_info=Model.SEGMENT)
     recordingchannel = FParent(type_info=Model.RECORDINGCHANNEL)
-    metadata         = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section         = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.ANALOGSIGNAL] = AnalogsignalModel
 
@@ -336,6 +369,6 @@ class IrregularlySampledSignalModel(Model):
 
     segment          = FParent(type_info=Model.SEGMENT)
     recordingchannel = FParent(type_info=Model.RECORDINGCHANNEL)
-    metadata         = FChildren(type_info=Model.VALUE, name_mapping="metadata")
+    section         = FParent(type_info=Model.SECTION, name_mapping="metadata")
 
 Model._MODEL_MAP[Model.IRREGULARLYSAMPLEDSIGNAL] = IrregularlySampledSignalModel
