@@ -7,12 +7,17 @@
 # modify it under the terms of the GNU Lesser General Public
 # License (see LICENSE.txt).
 
+from odml.doc import BaseDocument
 from odml.section import BaseSection
 from odml.property import BaseProperty
 from odml.value import BaseValue
 from gnodeclient.result.adapt_mixins import WithLocation, WithBlock
 
 
+class Document(WithLocation, BaseDocument):
+    pass
+
+
 class Section(WithLocation, WithBlock, BaseSection):
     pass
 
