@@ -18,14 +18,14 @@ from __future__ import print_function, absolute_import, division
 import numpy
 import quantities as pq
 
-#import odml
+import odml
 import odml.base
 import odml.section
 import odml.property
 import odml.value
 import neo
 
-from gnodeclient.result.adapt_odml import Section, Property, Value
+from gnodeclient.result.adapt_odml import Document, Section, Property, Value
 from gnodeclient.result.adapt_neo import Block, Segment, EventArray, Event, EpochArray, Epoch, \
     RecordingChannelGroup, RecordingChannel, Unit, SpikeTrain, Spike, AnalogSignalArray, \
     AnalogSignal, IrregularlySampledSignal
@@ -39,7 +39,7 @@ class ResultDriver(object):
     A result driver is used to convert internally used model objects into
     objects that are returned and handled by the Session class of the client
     API. The result driver is further more responsible for the creation of
-    proxy objects from permalink or location stings.
+    proxy objects from resource URL or location stings.
     """
 
     def __init__(self, store):
@@ -119,6 +119,7 @@ class NativeDriver(ResultDriver):
         Model.ANALOGSIGNALARRAY: AnalogSignalArray,
         Model.ANALOGSIGNAL: AnalogSignal,
         Model.IRREGULARLYSAMPLEDSIGNAL: IrregularlySampledSignal,
+        Model.DOCUMENT: Document,
         Model.SECTION: Section,
         Model.PROPERTY: Property,
         Model.VALUE: Value,
@@ -139,6 +140,7 @@ class NativeDriver(ResultDriver):
         Model.ANALOGSIGNALARRAY: neo.AnalogSignalArray,
         Model.ANALOGSIGNAL: neo.AnalogSignal,
         Model.IRREGULARLYSAMPLEDSIGNAL: neo.IrregularlySampledSignal,
+        Model.DOCUMENT: odml.doc.Document,
         Model.SECTION: odml.section.Section,
         Model.PROPERTY: odml.property.Property,
         Model.VALUE: odml.value.Value,
@@ -148,6 +150,12 @@ class NativeDriver(ResultDriver):
     # Methods
     #
 
+    @classmethod
+    def get_model_by_obj(cls, obj):
+        for model_name, model in cls.RW_MAP.items():
+            if isinstance(obj, model):
+                return Model.create(model_name)
+
     def to_result(self, obj):
         """
         Converts a model into a usable result.
@@ -199,6 +207,9 @@ class NativeDriver(ResultDriver):
                             setattr(native, "_property", proxy)
                         elif obj.model == Model.PROPERTY and field_name == "parent":
                             setattr(native, "_section", proxy)
+                        elif obj.model == Model.SECTION and field_name in \
+                                ["document", "section"]:
+                            setattr(native, "_parent", proxy)
                         else:
                             setattr(native, field_name, proxy)
 
@@ -231,6 +242,11 @@ class NativeDriver(ResultDriver):
                         q = pq.Quantity(data, units)
                         setattr(native, field_name, q)
 
+                elif obj.model == 'value' and field_name in \
+                        ['checksum', 'encoder'] and field_val is None:
+                    # special case for odML Value
+                    continue
+
                 elif hasattr(native, field_name):
                     setattr(native, field_name, field_val)
 
@@ -239,12 +255,14 @@ class NativeDriver(ResultDriver):
         else:
             return obj
 
-    def to_model(self, obj):
+    def to_model(self, obj, in_memory=False):
         """
         Converts a native neo or odml object into model object.
 
-        :param obj: The object to convert.
-        :type obj: object
+        :param obj:         The object to convert.
+        :type obj:          object
+        :param in_memory:   store array data to disk (False) or keep inside the
+                            converted model (True)
 
         :returns: A new model object.
         :rtype: Model
@@ -266,7 +284,20 @@ class NativeDriver(ResultDriver):
         for field_name in model_obj:
             field = model_obj.get_field(field_name)
             if field.type_info != "datafile":  # non-data fields
-                if hasattr(obj, field_name):
+                if model_obj.model == 'section' and field_name \
+                                            in ['document', 'section']:
+                    if model_obj.document is not None or \
+                                    model_obj.section is not None:
+                        continue
+
+                    parent = getattr(obj, 'parent')
+                    if parent is not None and hasattr(parent, 'location'):
+                        if isinstance(parent, odml.doc.Document):
+                            model_obj['document'] = parent.location
+                        elif isinstance(parent, odml.section.BaseSection):
+                            model_obj['section'] = parent.location
+
+                elif hasattr(obj, field_name):
                     field_val = getattr(obj, field_name, field.default)
 
                     # special treatment for the location field
@@ -299,23 +330,33 @@ class NativeDriver(ResultDriver):
                         model_obj[field_name] = field_val
 
             else:  # datafile fields
-                if field_name == "signal" and model_obj.model in (Model.ANALOGSIGNAL, Model.ANALOGSIGNALARRAY,
-                                                                  Model.IRREGULARLYSAMPLEDSIGNAL):
-                    units = obj.dimensionality.string
-                    datafile_location = self.store.set_array(obj, temporary=True)
-                    model_obj[field_name] = {"units": units, "data": datafile_location}
-                elif field_name == "times" and model_obj.model == Model.SPIKETRAIN:
-                    units = obj.dimensionality.string
-                    datafile_location = self.store.set_array(obj, temporary=True)
-                    model_obj[field_name] = {"units": units, "data": datafile_location}
-                elif hasattr(obj, field_name):
-                    field_val = getattr(obj, field_name, field.default)
-                    if field_val is not None:
-                        if hasattr(field_val, "dimensionality"):
-                            units = field_val.dimensionality.string
-                        else:
-                            units = None
-                        datafile_location = self.store.set_array(field_val, temporary=True)
-                        model_obj[field_name] = {"units": units, "data": datafile_location}
+                is_array_1 = (
+                    field_name == "signal" and model_obj.model in
+                    (Model.ANALOGSIGNAL, Model.ANALOGSIGNALARRAY,
+                     Model.IRREGULARLYSAMPLEDSIGNAL)
+                )
+                is_array_2 = (
+                    field_name == "times" and
+                    model_obj.model == Model.SPIKETRAIN
+                )
 
-        return model_obj
+                data_array = None
+                units = None
+
+                if is_array_1 or is_array_2:
+                    data_array = obj
+                elif hasattr(obj, field_name):
+                    data_array = getattr(obj, field_name, field.default)
+
+                if data_array is None:
+                    continue
+
+                if hasattr(data_array, "dimensionality"):
+                    units = data_array.dimensionality.string
+                if in_memory:
+                    location_or_obj = data_array
+                else:
+                    location_or_obj = self.store.set_array(data_array, temporary=True)
+                model_obj[field_name] = {"units": units, "data": location_or_obj}
+
+        return model_obj
\ No newline at end of file
