@@ -16,9 +16,11 @@ functions operate on a global, application wide session object.
 
 from __future__ import print_function, absolute_import, division
 
+import os
 from gnodeclient.conf import Configuration
 from gnodeclient.store.caching_rest_store import CachingRestStore
 from gnodeclient.result.result_driver import NativeDriver
+from gnodeclient.store.dumper import Dumper
 
 __all__ = ("Session", "create", "close")
 
@@ -49,11 +51,16 @@ class Session(object):
                                         password=self.__options["password"], cache_location=self.options["cache_dir"])
         self.__store.connect()
         self.__driver = NativeDriver(self.__store)
+        self.__dumper = Dumper(self.__driver)
 
     #
     # Properties
     #
 
+    @property
+    def driver(self):
+        return self.__driver
+
     @property
     def options(self):
         """
@@ -102,6 +109,7 @@ class Session(object):
             res = self.__driver.to_result(obj)
         else:
             res = None
+
         return res
 
     def set(self, entity, avoid_collisions=False):
@@ -121,75 +129,20 @@ class Session(object):
         res = self.__driver.to_result(mod)
         return res
 
-    def set_all(self, entity, avoid_collisions=False, fail=False):
+    def set_all(self, entity, avoid_collisions=False):
         """
-        Saves object with all downstream relationships on the G-Node service.
-        Updates IDs for a given object and all its relationships recursively.
+        (FULL) Save a modified or created object on the G-Node service.
 
         :param entity: The object to store (Neo or odML).
         :type entity: object
         :param avoid_collisions: If true, check if the modified object collide with changes on the server.
         :type avoid_collisions: bool
-        :param fail: skip objects that failed to sync / fail on first sync failure
-        :type fail: bool
-
-        :returns: list of exceptions that did occur.
-        :rtype: object
         """
-        todo = [entity]  # a stack of objects to submit
-        processed = []  # collector of locations of processed objects
-        to_clean = []  # collector of locations of objects to delete
-        exceptions = []  # collector of exceptions
-
-        while len(todo) > 0:
-            local_native = todo[0]
-            local_model = self.__driver.to_model(local_native)
-            if local_model.location in processed:
-                continue  # workaround to avoid duplicate processing for Neo
-
-            try:
-                remote_model = self.__store.set(local_model, avoid_collisions)
-                processed.append(remote_model.location)
-                # below is a "side-effect" needed to have correct parents for children
-                # and to avoid processing the same object twice, in case of a non-tree
-                # hierarchies
-                local_native.location = remote_model.location
-
-            except Exception, e:  # some object fails to sync (catch HTTP only?)
-                if fail:
-                    raise e
-                else:
-                    exceptions.append(e)
-                    if len(local_model.child_fields) > 0:
-                        continue
-            finally:
-                todo.remove(local_native)  # not to forget to remove processed object
-
-            for field_name in local_model.child_fields:
-                # set difference between the actual remote and local children
-                # references determines the list of children to delete
-                local_children = local_model[field_name] or []
-                remote_children = remote_model[field_name] or []
-                to_clean += list(set(remote_children) - set(local_children))
-
-                if hasattr(local_native, field_name):
-                    children = getattr(local_native, field_name, [])
-                    # skip empty lazy-loaded proxy relations
-                    if not (hasattr(children, '_is_loaded') and not getattr(children, '_is_loaded')) and\
-                            (children is not None):
-                        for obj in children:
-                            loc = getattr(obj, 'location', None)
-                            if not (loc is not None and loc in processed):
-                                todo.append(obj)
-
-        # cleaning removed objects
-        for location in to_clean:
-            try:
-                self.__store.delete(location)
-            except Exception, e:
-                exceptions.append(e)
-
-        return exceptions
+        path = self.__dumper.dump(entity)
+        mod = self.__store.set_delta(path, avoid_collisions)
+        res = self.__driver.to_result(mod)
+        os.remove(path)
+        return res
 
     def delete(self, entity):
         """
@@ -210,19 +163,20 @@ class Session(object):
 
         .. code-block:: python
 
+            [{
+               "user": "/api/v1/user/user/neo/",
+               "access_level": 1  # 1-read-only
+            },
             {
-                "safety_level": 1, # 1-private, 2-friendly, 3-public
-                "shared_with": {
-                    "bob": 1, # 1-read-only
-                    "jeff", 2 # 2-read-write
-                }
-            }
+               "user": "/api/v1/user/user/bob/",
+               "access_level": 2  # 2-read-write
+            }]
 
         :param entity: The entity to get or set permissions from/to.
         :type entity: object
         :param permissions: new permissions to apply.
 
-        :type permissions: dict
+        :type permissions: list
 
         :returns: actual object permissions
         :rtype: dict (see above)
