@@ -3,6 +3,7 @@ Miscellaneous helper functions.
 """
 
 import random
+import string
 
 try:
     import urlparse
@@ -12,10 +13,7 @@ except ImportError:
 
 
 def id_from_location(location):
-    if location.strip("/").endswith("/data"):
-        location = location[0:len(location) - 5]
-    ident = urlparse.urlparse(location).path.strip("/").split("/")[-1]
-    return ident
+    return urlparse.urlparse(location).path.strip("/").split("/")[4]
 
 
 def random_str(length=16, prefix=None, separator="_", alphabet=None):
@@ -25,3 +23,11 @@ def random_str(length=16, prefix=None, separator="_", alphabet=None):
     if prefix is not None and len(prefix) > 0:
         rnd = prefix + separator + rnd
     return rnd
+
+
+def random_base32(length=10):
+    alphabet = tuple(list('0123456789' + string.ascii_uppercase)[:32])
+    uid = random.choice(alphabet[1:])
+    for i in range(length - 1):
+        uid += random.choice(alphabet)
+    return uid
\ No newline at end of file
